import React, { useState, useCallback, useEffect,useMemo } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear, scaleTime, scaleOrdinal,scaleLog, max, format, timeFormat, extent,nest } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import ReactDropdown from 'react-dropdown';
import { ColorLegend } from './colorLegend';

const width = 960;
const height = 500;
const margin = { top: 20, right: 120, bottom: 55, left: 90 };
const xAxisLabelOffset = 50;
const fadeOpacity = 0.5;


// This is used to move the label from the y axis values
const yAxisLabelOffset = 60;

const App = () => {
  const data = useData();
  const [hoveredValue, setHoveredValue] = useState(null);
  
  console.log(hoveredValue)
  const yAttribute = 'new_cases';

  if (!data) {
    return <pre>Loading...</pre>;
  }
  
  const colorScale = scaleOrdinal()
    .domain(["India", "Brazil", "United States", "Russia","Peru","Bangladesh","Chile","Mexico","Saudi Arabia","Spain"])
    .range(['#E6842A', '#137B80', '#8E6C8A', 'blue','#E8942A','green','gray','purple','red','yellow']);
  	
   
// Filter Data
  const filteredData = data.filter(function(d) 
	{ 
		if(d["location"] == 'India'||
       d["location"] =='Brazil'||
       d["location"] =='United States'||
       d["location"] =='Russia'||
       d["location"] =='Peru'||
       d["location"]=='Bangladesh'||
       d["location"]=='Chile'||
       d["location"]=='Mexico'||
       d["location"]=='Saudi Arabia'||
       d["location"]=='Spain'
      ){ 
      return d;
    } 
 });
  console.log(filteredData)
 	const hoveredfilteredData =filteredData.filter(d=>d["location"] == hoveredValue)

	//console.log(filteredData.filter(d=>d["location"] == hoveredValue))
  
  
  var countydata = nest() 
    .key(function(d) { return d.location;})
    .rollup(function(d) {
     var arr=d.map(function(g){ return { date: g.date, new_cases: g[yAttribute]}})
  	return({data_con: arr})
    })
    .entries(filteredData)
    
   //console.log(countydata);
   console.log(countydata.map(d=>(d.key)));
	  console.log(countydata.map(d=>(d.value.data_con[30].new_cases)));
  
  const contries_val=countydata.map(d=>(d.key))
  const lastday_val=countydata.map(d=>(d.value.data_con[30].new_cases));
  
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const yValue = d => d[yAttribute];

  const xValue = d => d.date;
  const xAxisLabel = 'Date';
  const xAxisTickFormat = timeFormat('%d');
  const xScale = scaleTime()
    .domain(extent(filteredData, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
   .domain([0,40000])
   .range([innerHeight,0 ])
   .nice();


  return (
    <>
      <svg width={width} height={height}>
        <g transform={`translate(${margin.left},${margin.top})`}>
          <AxisBottom
            xScale={xScale}
            innerHeight={innerHeight}
            tickFormat={xAxisTickFormat}
            tickOffset={7}
          />
          <text
            className="axis-label"
            x={innerWidth / 2}
            y={innerHeight + xAxisLabelOffset}
            textAnchor="middle"
          >
            {xAxisLabel}
          </text>
          <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={7} />
          <text
            className="axis-label"
            textAnchor="middle"
            transform={`translate(${-yAxisLabelOffset},${innerHeight /
              2}) rotate(-90)`}
          >
            {"new cases"}
          </text>
          
          {countydata.map(d=>{
            return(
            <g opacity={hoveredValue ? fadeOpacity : 1}>
              <Marks
            data={d.value.data_con}
            country={d.key}
            xScale={xScale}
            yScale={yScale}
            xValue={xValue}
            yValue={yValue}
            colorScale={colorScale}
            tooltipFormat={xAxisTickFormat}
            circleRadius={1}
          	/>
          </g>
          )})}
          
          <ColorLegend 
              colorScale={colorScale}
            	tickSpacing={10}
      			  tickSpacing={25}
            	innerWidth={innerWidth}
            	contries_val={contries_val}
              lastday_val={lastday_val}
            	yValue={yValue}
            yScale={yScale} 
             onHover={setHoveredValue}
              hoveredValue={hoveredValue}
              fadeOpacity={fadeOpacity}
          />
           <Marks
            data={hoveredfilteredData}
            xScale={xScale}
            yScale={yScale}
            xValue={xValue}
            yValue={yValue}
            colorScale={colorScale}
            tooltipFormat={xAxisTickFormat}
            circleRadius={1}
          	/>
        </g>
      </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
